.. _podcast_overview:

*******
Podcast
*******

Podcasts are :ref:`blogs <blog_overview>` that have some additional features to
better support podcasting.

There are some additional fields that are available for podcasts:

Itunes Artwork
==============
The image that will be used in the podcast feed as the iTunes artwork.
